@@ -37,7 +37,7 @@ class template:
         for p in hh.sp:
             self.calc_tax(p)
             self.calc_non_refundable_tax_credits(p, hh)
-            self.calc_div_tax_credit(p)
+            self.div_tax_credit(p)
             p.fed_return['net_tax_liability'] = max(0,
                 p.fed_return['gross_tax_liability'] - p.fed_return['non_refund_credits']
                 - p.fed_div_tax_credit)
@@ -57,9 +57,11 @@ class template:
         """
         p.taxable_div = (self.div_elig_factor * p.div_elig
                          + self.div_other_can_factor * p.div_other_can)
+        p.taxable_cap_gains = self.cap_gains_rate * max(0, p.net_cap_gains)
         p.fed_return['gross_income'] = (p.inc_work + p.inc_ei + p.inc_oas
                                         + p.inc_gis + p.inc_cpp + p.inc_rpp
-                                        + p.pension_split + p.cap_gains
+                                        + p.pension_split + p.taxable_div
+                                        + p.taxable_cap_gains
                                         + p.inc_othtax + p.inc_rrsp)
 
     def calc_net_income(self, p):
@@ -116,7 +118,7 @@ class template:
 
     def chcare(self, p, hh):
         """
-        Déduction pour frais de garde.
+        Fonction qui calcule la déduction fédérale pour frais de garde.
 
         Parameters
         ----------
@@ -127,7 +129,7 @@ class template:
         Returns
         -------
         float
-            Montant de la déduction pour frais de garde
+            Montant de la déduction pour frais de garde.
 
             Cette fonction calcule le montant reçu en fonction des frais de garde,
             de l'âge des enfants et du revenu le moins élevé du couple. Le montant
@@ -146,7 +148,7 @@ class template:
 
     def cpp_deduction(self, p):
         """
-        Déduction pour les cotisations RPC/RRQ pour les travailleurs autonomes.
+        Fonction qui calcule la déduction pour les cotisations au RRQ / RPC pour les travailleurs autonomes.
 
         Parameters
         ----------
@@ -156,7 +158,7 @@ class template:
         Returns
         -------
         float
-            Montant de la déduction
+            Montant de la déduction.
         """
         try:
             return p.contrib_cpp_self / 2
@@ -166,7 +168,7 @@ class template:
 
     def qpip_deduction(self, p):
         """
-        Déduction pour les cotisations RQAP pour les travailleurs autonomes.
+        Fonction qui calcule la déduction pour les cotisations au RQAP pour les travailleurs autonomes.
 
         Parameters
         ----------
@@ -176,25 +178,25 @@ class template:
         Returns
         -------
         float
-            Montant de la déduction
+            Montant de la déduction.
         """
         return self.qpip_deduc_rate * p.contrib_qpip_self
 
     def calc_deduc_net_income(self, p):
         """
         Fonction qui calcule les déductions suivantes:
-        - Pertes en capital net des autres années.
-        - Déduction pour gain en capital exonéré.
+        1. Pertes en capital net des autres années;
+        2. Déduction pour gain en capital exonéré.
 
-        Permet une déduction maximale égale aux gains en capitaux taxables nets.
+        Permet une déduction maximale égale aux gains en capital taxables nets.
 
         Parameters
         ----------
         p: Person
             instance de la classe Person
         """
-        p.fed_return['deductions_net_inc'] = min(p.cap_gains,
-                                                 p.cap_losses + p.cap_gains_exempt)
+        p.fed_return['deductions_net_inc'] = min(p.taxable_cap_gains,
+            p.prev_cap_losses + self.cap_gains_rate * p.cap_gains_exempt)
 
     def calc_tax(self, p):
         """
@@ -215,7 +217,7 @@ class template:
         """
         Fonction qui calcule les crédits d'impôt non-remboursables.
 
-        Cette fonction fait la somme de tous les crédits d'impôt modélisés.
+        Cette fonction fait la somme de tous les crédits modélisés en appelant les fonctions *compute_basic_amount*, *get_age_cred*, *get_cpp_contrib_cred*, *get_qpip_cred*,, *get_qpip_self_cred*, *get_empl_cred*, *get_pension_cred*, *get_disabled_cred*, *get_med_exp_nr_cred*, et *get_donations_cred*. Celles-ci sont définies ci-après.
 
         Parameters
         ----------
@@ -236,11 +238,13 @@ class template:
             * (self.compute_basic_amount(p) + p.fed_age_cred
                + p.fed_cpp_contrib_cred + p.fed_qpip_cred +
                + p.fed_qpip_self_cred + p.fed_empl_cred + p.fed_pension_cred
-               + p.fed_disabled_cred + p.fed_med_exp_nr_cred + p.donation_cred))
+               + p.fed_disabled_cred + p.fed_med_exp_nr_cred)
+               + p.donation_cred)
 
     def compute_basic_amount(self, p):
         """
-        Fonction qui calcule le montant personnel de base des crédits d'impôts non-remboursables.
+        Fonction qui calcule le montant personnel de base.
+
         Le calcul de ce montant change en 2020.
 
         Parameters
@@ -251,15 +255,13 @@ class template:
         Returns
         -------
         float:
-            montant personnel de base
+            Montant personnel de base
         """
         return self.basic_amount
 
     def get_age_cred(self, p):
         """
-        Crédit d'impôt selon l'âge.
-
-        Ce crédit est non-remboursable.
+        Fonction qui calcule le crédit d'impôt non-remboursable en raison de l'âge.
 
         Parameters
         ----------
@@ -268,17 +270,18 @@ class template:
 
         Returns
         -------
-            Montant du crédit
+        float:
+            Montant du crédit.
         """
-        amount = self.age_cred_amount if p.age >= self.min_age_cred else 0
-        clawback = self.age_cred_claw_rate * max(0, p.fed_return['net_income'] - self.age_cred_exemption)
-        return max(0, amount - clawback)
+        if p.age < self.min_age_cred:
+            return 0
+
+        clawback = self.age_cred_claw_rate * max(0, p.fed_return['net_income'] - self.age_cred_exempt)
+        return max(0, self.age_cred_amount - clawback)
 
     def get_cpp_contrib_cred(self, p):
         """
-        Crédit d'impôt pour contributions RPC/RRQ.
-
-        Ce crédit est non-remboursable.
+        Fonction qui calcule le crédit d'impôt non-remboursable pour cotisations au RRQ / RPC.
 
         Parameters
         ----------
@@ -287,15 +290,14 @@ class template:
 
         Returns
         -------
-            Montant du crédit
+        float:
+            Montant du crédit.
         """
         return p.contrib_cpp + p.contrib_cpp_self / 2
 
     def get_qpip_cred(self, p):
         """
-        Crédit d'impôt pour contributions RQAP pour travailleur salarié.
-
-        Ce crédit est non-remboursable.
+        Fonction qui calcule le crédit d'impôt non-remboursable pour cotisations au RQAP de travailleur salarié.
 
         Parameters
         ----------
@@ -304,15 +306,14 @@ class template:
 
         Returns
         -------
-            Montant du crédit
+        float:
+            Montant du crédit.
         """
         return p.contrib_qpip
 
     def get_qpip_self_cred(self, p):
         """
-        Crédit d'impôt pour contributions RQAP pour travailleur autonome.
-
-        Ce crédit est non-remboursable.
+        Crédit d'impôt non-remboursable pour cotisations au RQAP de travailleur autonome.
 
         Parameters
         ----------
@@ -321,7 +322,8 @@ class template:
 
         Returns
         -------
-            Montant du crédit
+        float:
+            Montant du crédit.
         """
         return p.contrib_qpip_self - p.fed_qpip_deduction
 
@@ -338,15 +340,14 @@ class template:
 
         Returns
         -------
-            Montant du crédit
+        float:
+            Montant du crédit.
         """
         return min(self.empl_cred_max, p.inc_earn)
 
     def get_pension_cred(self, p, hh):
         """
-        Crédit d'impôt pour revenu de retraite.
-
-        Ce crédit est non-remboursable.
+        Crédit d'impôt non-remboursable pour revenu de retraite.
 
         Parameters
         ----------
@@ -355,7 +356,8 @@ class template:
 
         Returns
         -------
-            Montant du crédit
+        float:
+            Montant du crédit.
         """
         if hh.elig_split and (p.age < self.pension_cred_min_age_split):
             other_p = hh.sp[1 - hh.sp.index(p)]
@@ -379,6 +381,7 @@ class template:
 
         Returns
         -------
+        float:
             Montant du crédit
         """
         return self.disability_cred_amount if p.disabled else 0
@@ -399,18 +402,20 @@ class template:
 
         Returns
         -------
+        float:
             Montant du crédit
         """
         if p is not min(hh.sp, key=lambda p: p.fed_return['net_income']):
             return 0
 
         med_exp = sum([p.med_exp for p in hh.sp]
-            + [d.med_exp for d in hh.dep if d.age <= self.med_exp_nr_cred_max_age])
+                       + [d.med_exp for d in hh.dep
+                          if d.age < self.med_exp_nr_cred_max_age])
         clawback = min(self.med_exp_nr_cred_max_claw,
                        self.med_exp_nr_cred_rate * p.fed_return['net_income'])
         med_exp_other_dep = sum([d.med_exp for d in hh.dep
-                                 if d.age > self.med_exp_nr_cred_max_age])
-        # rem: we assume that dependents over 16 have zero net income (otherwise there would be a clawback)
+                                 if d.age >= self.med_exp_nr_cred_max_age])
+        # rem: we assume that dependents 18 and over have zero net income (otherwise there would be a clawback)
         return max(0, max(0, med_exp - clawback) + med_exp_other_dep)
 
     def get_donations_cred(self, p):
@@ -430,7 +435,8 @@ class template:
             Montant du crédit
         """
         tot_donation = (
-            min(self.donation_frac_net * p.fed_return['net_income'], p.donation) + p.gift)
+            min(self.donation_frac_net * p.fed_return['net_income'],
+            p.donation) + p.gift)
 
         if tot_donation <= self.donation_low_cut:
             return tot_donation * self.donation_low_rate
@@ -444,7 +450,7 @@ class template:
                     + donation_high_inc * self.donation_high_rate
                     + donation_low_inc * self.donation_med_rate)
 
-    def calc_div_tax_credit(self, p):
+    def div_tax_credit(self, p):
         """
         Crédit d'impôt pour dividendes
 
@@ -470,8 +476,8 @@ class template:
         """
         p.fed_abatment_qc = self.abatment(p, hh)
         p.fed_ccb = self.ccb(p, hh)
-        p.fed_witb = self.witb(p, hh)
-        p.fed_witbds = self.witbds(p, hh)
+        p.fed_witb = self.get_witb(p, hh)
+        p.fed_witbds = self.get_witbds(p, hh)
         p.fed_med_exp = self.med_exp(p, hh)
         p.fed_gst_hst_credit = self.gst_hst_credit(p, hh)
 
@@ -547,7 +553,7 @@ class template:
             else:
                 return max(0, amount - clawback)
 
-    def witb(self, p, hh):
+    def get_witb(self, p, hh):
         """
         Prestation fiscale pour le revenu de travail (PFRT/WITB). À partir de 2019,
         cela devient l'Allocation canadienne pour les travailleurs (ACT/CWB).
@@ -565,31 +571,33 @@ class template:
         float
             Montant de la PFRT (WITB)
         """
+        self.witb = self.witb_params['qc'] if hh.prov == 'qc' else self.witb_params['on']
+
         if not hh.couple:
-            base = self.witb_base_single_qc
-            rate = self.witb_rate_single_dep_qc if hh.nkids_0_18 else self.witb_rate_qc
-            witb_max = self.witb_max_single_dep_qc if hh.nkids_0_18 else self.witb_max_single_qc
-            exemption = self.witb_exemption_single_dep_qc if hh.nkids_0_18 else self.witb_exemption_single_qc
+            base = self.witb['base_single']
+            rate = self.witb['rate_single_dep'] if hh.nkids_0_18 else self.witb['rate']
+            witb_max = self.witb['max_single_dep'] if hh.nkids_0_18 else self.witb['max_single']
+            exemption = self.witb['exempt_single_dep'] if hh.nkids_0_18 else self.witb['exempt_single']
             factor = 1
         else:
-            base = self.witb_base_couple_qc
-            rate = self.witb_rate_couple_dep_qc if hh.nkids_0_18 else self.witb_rate_qc
-            witb_max = self.witb_max_couple_dep_qc if hh.nkids_0_18 else self.witb_max_couple_qc
-            exemption = self.witb_exemption_couple_dep_qc if hh.nkids_0_18 else self.witb_exemption_couple_qc
+            base = self.witb['base_couple']
+            rate = self.witb['rate_couple_dep'] if hh.nkids_0_18 else self.witb['rate']
+            witb_max = self.witb['max_couple_dep'] if hh.nkids_0_18 else self.witb['max_couple']
+            exemption = self.witb['exempt_couple_dep'] if hh.nkids_0_18 else self.witb['exempt_couple']
             if hh.fam_inc_work > 0:
                 factor = p.inc_work / hh.fam_inc_work
             else:
                 factor = 1/2
 
         return factor * self.compute_witb_witbds(p, hh, rate, base, witb_max,
-                                                 self.witb_claw_rate_qc, exemption)
+                                                 self.witb['claw_rate'], exemption)
 
-    def witbds(self, p, hh):
+    def get_witbds(self, p, hh):
         """
         Supplément pour invalidité à la prestation fiscale pour le revenu de travail
         (SIPFRT/WITBDS).
-        À partir de 2019, cela devient le supplément pour invalidité à l'Allocation canadienne pour les travailleurs (ACT).
-
+        À partir de 2019, cela devient le supplément pour invalidité
+        à l'Allocation canadienne pour les travailleurs (ACT).
 
         Parameters
         ----------
@@ -597,6 +605,7 @@ class template:
             instance de la classe Person
         hh: Hhold
             instance de la classe Hhold
+
         Returns
         -------
         float
@@ -606,19 +615,19 @@ class template:
             return 0
 
         couple_dis = sum([p.disabled for p in hh.sp]) == 2
-        claw_rate = self.witb_dis_claw_rate_qc
+        claw_rate = self.witb['dis_claw_rate']
         if not hh.couple:
-            rate = self.witb_dis_rate_single_qc
-            exemption = self.witb_dis_exemption_single_dep_qc if hh.nkids_0_18 else self.witb_dis_exemption_single_qc
+            rate = self.witb['dis_rate_single']
+            exemption = self.witb['dis_exempt_single_dep'] if hh.nkids_0_18 else self.witb['dis_exempt_single']
         else:
-            rate = self.witb_dis_rate_couple_qc
-            exemption = self.witb_dis_exemption_couple_dep_qc if hh.nkids_0_18 else self.witb_dis_exemption_couple_qc
+            rate = self.witb['dis_rate_couple']
+            exemption = self.witb['dis_exempt_couple_dep'] if hh.nkids_0_18 else self.witb['dis_exempt_couple']
             if couple_dis:
-                claw_rate = self.witb_dis_couple_claw_rate_qc
-                exemption = self.witb_dis_exemption_couple_dep_qc if hh.nkids_0_18 else self.witb_dis_exemption_couple_qc
+                claw_rate = self.witb['dis_couple_claw_rate']
+                exemption = self.witb['dis_exempt_couple_dep'] if hh.nkids_0_18 else self.witb['dis_exempt_couple']
 
-        return self.compute_witb_witbds(p, hh, rate, self.witb_dis_base_qc,
-                                        self.witb_dis_max_qc, claw_rate, exemption)
+        return self.compute_witb_witbds(p, hh, rate, self.witb['dis_base'],
+                                        self.witb['dis_max'], claw_rate, exemption)
 
     def compute_witb_witbds(self, p, hh, rate, base, witb_max, claw_rate,
                             exemption):
